free_aligned_sized

Function free_aligned_sized 

pub unsafe extern "C" fn free_aligned_sized(
    ptr: *mut c_void,
    alignment: size_t,
    size: size_t,
)
Deallocates previously-allocated memory region referenced by ptr.

This makes the space available for future allocations.

If ptr is null, no action occurs.

Safety

The behavior is undefined if:

  • ptr does not match a pointer earlier returned by aligned_alloc, or alignment and size do not match the values passed to aligned_alloc, or
  • the memory region referenced by ptr has been deallocated.